==> banking-branch_14.8.0.0.0-Plus1.zip: banking-branch_14.8.0.0.0-Plus1_20250419/content/banking-branch/14.8.0.0.0/troug/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-43DD34DF-F7DF-4DF1-A9B0-4DDA8F96270B"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Troubleshooting Technical Flows",
                    "href":"troubleshooting-technical-flows.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1.1 </span> Where is the Problem",
                            "href":"where-is-problem.html"
                        },
                        {
                            "title":"<span class=\"secnum\">1.2 </span> Preliminary Checks from UI",
                            "href":"preliminary-checks-ui.html"
                        },
                        {
                            "title":"<span class=\"secnum\">1.3 </span> Preliminary Checks from Service Log Files",
                            "href":"preliminary-checks-service-log-files.html"
                        },
                        {
                            "title":"<span class=\"secnum\">1.4 </span> Troubleshooting Using Zipkin Traces",
                            "href":"troubleshooting-using-zipkin-traces.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.4.1 </span> Known Issues for Zipkin",
                                    "href":"known-issues-zipkin.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">1.5 </span> Troubleshooting Logs using ELK Stack",
                            "href":"troubleshooting-logs-using-elk-stack.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.5.1 </span> Set Up ELK",
                                    "href":"set-elk.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.5.2 </span> Export Logs in Kibana",
                                    "href":"export-logs-kibana.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">1.6 </span> Troubleshooting Environmental Issues",
                            "href":"troubleshooting-environmental-issues.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.6.1 </span> Possible Issues While Deploying Services",
                                    "href":"possible-issues-while-deploying-services.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.6.2 </span> Possible Issues While Logging in and Launching Screen",
                                    "href":"possible-issues-while-logging-and-launching-screen.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.6.3 </span> Troubleshooting Network Issues in Advice",
                                    "href":"troubleshooting-network-issues-advice.html"
                                }
                            ]
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Health Checks and Verifications",
                    "href":"health-checks-and-verifications.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">2.1 </span> Known Issues for WebLogic",
                            "href":"known-issues-weblogic.html"
                        },
                        {
                            "title":"<span class=\"secnum\">2.2 </span> Application Services",
                            "href":"application-services.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Troubleshooting Functional Workflows",
                    "href":"troubleshooting-functional-workflows.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">3.1 </span> Subdomains of Oracle Banking Branch",
                            "href":"subdomains-oracle-banking-branch.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.2 </span> High-Level Flow for Cash Deposit",
                            "href":"high-level-flow-cash-deposit.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">3.2.1 </span> First Level Issues",
                                    "href":"first-level-issues.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">3.2.2 </span> Verify Transaction Data",
                                    "href":"verify-transaction-data.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">3.3 </span> Update Process Log Table",
                            "href":"update-process-log-table.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.4 </span> Troubleshooting Payment Service Integration",
                            "href":"troubleshooting-payment-service-integration.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.5 </span> Configure Oracle Banking Routing Hub",
                            "href":"configure-oracle-banking-routing-hub.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.6 </span> Purging and Archival",
                            "href":"purging-and-archival.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.7 </span> Troubleshooting Process Runtime Screens",
                            "href":"troubleshooting-process-runtime-screens.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.8 </span> EOD Configuration",
                            "href":"eod-configuration.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">3.8.1 </span> Before You Begin",
                                    "href":"you-begin-eod-configuration.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">3.8.2 </span> Create EOD Workflow",
                                    "href":"create-eod-workflow.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">3.8.3 </span> Configure EOD Batch",
                                    "href":"configure-eod-batch.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">3.8.4 </span> Run EOD Batch",
                                    "href":"run-eod-batch.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">3.9 </span> Troubleshooting Projection Schema Failure",
                            "href":"troubleshooting-projection-schema-failure.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">4 </span> Troubleshooting Deployment Errors/Exceptions",
                    "href":"troubleshooting-deployment-errors-exceptions.html"
                },
                {
                    "title":"<span class=\"secnum\">A </span> Error Codes and Messages",
                    "href":"error-codes-and-messages.html"
                }
            ]
        }
    ]
});

==> banking-branch_14.8.1.0.0-Plus1.zip: banking-branch_14.8.1.0.0-Plus1_20251105/content/banking-branch/14.8.1.0.0/troug/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-43DD34DF-F7DF-4DF1-A9B0-4DDA8F96270B",
                    "topics":[
                        {
                        },
                        {
                        },
                        {
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Troubleshooting Technical Flows",
                    "href":"troubleshooting-technical-flows.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1.1 </span> Where is the Problem",
                            "href":"where-is-problem.html"
                        },
                        {
                            "title":"<span class=\"secnum\">1.2 </span> Preliminary Checks from UI",
                            "href":"preliminary-checks-from-ui.html"
                        },
                        {
                            "title":"<span class=\"secnum\">1.3 </span> Preliminary Checks from Service Log Files",
                            "href":"preliminary-checks-from-service-log-files.html"
                        },
                        {
                            "title":"<span class=\"secnum\">1.4 </span> Troubleshooting Using Zipkin Traces",
                            "href":"troubleshooting-using-zipkin-traces.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.4.1 </span> Known Issues for Zipkin",
                                    "href":"known-issues-zipkin.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">1.5 </span> Troubleshooting Logs using ELK Stack",
                            "href":"troubleshooting-logs-using-elk-stack.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.5.1 </span> Set Up ELK",
                                    "href":"elk.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.5.2 </span> Export Logs in Kibana",
                                    "href":"export-logs-kibana.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">1.6 </span> Troubleshooting Environmental Issues",
                            "href":"troubleshooting-environmental-issues.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.6.1 </span> Possible Issues While Deploying Services",
                                    "href":"possible-issues-while-deploying-services.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.6.2 </span> Possible Issues While Logging in and Launching Screen",
                                    "href":"possible-issues-while-logging-launching-screen.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.6.3 </span> Troubleshooting Network Issues in Advice",
                                    "href":"troubleshooting-network-issues-advice.html"
                                }
                            ]
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Health Checks and Verifications",
                    "href":"health-checks-verifications.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">2.1 </span> Known Issues for WebLogic",
                            "href":"known-issues-weblogic.html"
                        },
                        {
                            "title":"<span class=\"secnum\">2.2 </span> Application Services",
                            "href":"application-services.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Troubleshooting Functional Workflows",
                    "href":"troubleshooting-functional-workflows.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">3.1 </span> Subdomains of Oracle Banking Branch",
                            "href":"subdomains-oracle-banking-branch.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.2 </span> High-Level Flow for Cash Deposit",
                            "href":"high-level-flow-cash-deposit.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">3.2.1 </span> First Level Issues",
                                    "href":"first-level-issues.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">3.2.2 </span> Verify Transaction Data",
                                    "href":"verify-transaction-data.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">3.3 </span> Update Process Log Table",
                            "href":"update-process-log-table.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.4 </span> Troubleshooting Payment Service Integration",
                            "href":"troubleshooting-payment-service-integration.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.5 </span> Configure Oracle Banking Routing Hub",
                            "href":"configure-oracle-banking-routing-hub.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.6 </span> Purging and Archival",
                            "href":"purging-archival.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.7 </span> Troubleshooting Process Runtime Screens",
                            "href":"troubleshooting-process-runtime-screens.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.8 </span> EOD Configuration",
                            "href":"eod-configuration.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">3.8.1 </span> Before You Begin",
                                    "href":"before-you-begin-eod-configuration.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">3.8.2 </span> Create EOD Workflow",
                                    "href":"create-eod-workflow.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">3.8.3 </span> Configure EOD Batch",
                                    "href":"configure-eod-batch.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">3.8.4 </span> Run EOD Batch",
                                    "href":"run-eod-batch.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">3.9 </span> Troubleshooting Projection Schema Failure",
                            "href":"troubleshooting-projection-schema-failure.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">4 </span> Troubleshooting Deployment Errors/Exceptions",
                    "href":"troubleshooting-deployment-errorsexceptions.html"
                },
                {
                    "title":"<span class=\"secnum\">A </span> Error Codes and Messages",
                    "href":"error-codes-messages.html"
                }
            ]
        }
    ]
});
